==> jc-1.4.0.tar.gz: gnu/regexp/RETokenPOSIX.h <==
// final class gnu.regexp.RETokenPOSIX

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class 92fd4d13ee48f3ea gnu_regexp_RETokenPOSIX
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenPOSIX_H_
#define _JC_gnu_regexp_RETokenPOSIX_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenPOSIX$sub_refs	_jc_gnu_regexp_RETokenPOSIX$sub_refs;
typedef struct _jc_gnu_regexp_RETokenPOSIX$sub_nonrefs	_jc_gnu_regexp_RETokenPOSIX$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenPOSIX$refs	_jc_gnu_regexp_RETokenPOSIX$refs;
typedef struct _jc_gnu_regexp_RETokenPOSIX$nonrefs	_jc_gnu_regexp_RETokenPOSIX$nonrefs;
typedef struct _jc_gnu_regexp_RETokenPOSIX$object	_jc_gnu_regexp_RETokenPOSIX$object;

typedef struct _jc_gnu_regexp_RETokenPOSIX$fields_struct	_jc_gnu_regexp_RETokenPOSIX$fields_struct;
typedef const struct _jc_gnu_regexp_RETokenPOSIX$vmethods	_jc_gnu_regexp_RETokenPOSIX$vmethods;
typedef const struct _jc_gnu_regexp_RETokenPOSIX$vtable	_jc_gnu_regexp_RETokenPOSIX$vtable;
typedef const struct _jc_gnu_regexp_RETokenPOSIX$vtype	_jc_gnu_regexp_RETokenPOSIX$vtype;

// Class fields structure
struct _jc_gnu_regexp_RETokenPOSIX$fields_struct {
	_jc_object_array	*s__5fnameTable;
	jint	ALNUM;
	jint	ALPHA;
	jint	BLANK;
	jint	CNTRL;
	jint	DIGIT;
	jint	GRAPH;
	jint	LOWER;
	jint	PRINT;
	jint	PUNCT;
	jint	SPACE;
	jint	UPPER;
	jint	XDIGIT;
};
extern _jc_gnu_regexp_RETokenPOSIX$fields_struct _jc_gnu_regexp_RETokenPOSIX$class_fields;

// Constructors
extern void _jc_gnu_regexp_RETokenPOSIX$method$_init$bfa5e4ad51d4d34a(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *, jint, jint, jboolean, jboolean);

// Virtual methods
extern void _jc_gnu_regexp_RETokenPOSIX$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *, struct _jc_java_lang_StringBuffer$object *);
extern jint _jc_gnu_regexp_RETokenPOSIX$method$getMinimumLength$13aeed906e65d975(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *);
extern jboolean _jc_gnu_regexp_RETokenPOSIX$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenPOSIX$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenPOSIX$method_info$getMinimumLength$13aeed906e65d975;
extern _jc_method _jc_gnu_regexp_RETokenPOSIX$method_info$match$d139de67a06a4f32;

// Static methods
extern void _jc_gnu_regexp_RETokenPOSIX$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jint _jc_gnu_regexp_RETokenPOSIX$method$intValue$f40b63b3de105c92(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_gnu_regexp_RETokenPOSIX$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *, struct _jc_java_lang_StringBuffer$object *);
	jint	(*getMinimumLength$13aeed906e65d975)(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *);
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *);
};

// Vtable
struct _jc_gnu_regexp_RETokenPOSIX$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenPOSIX$vmethods	gnu_regexp_RETokenPOSIX;
};

// Vtype
struct _jc_gnu_regexp_RETokenPOSIX$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenPOSIX$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenPOSIX$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenPOSIX$refs {
    _jc_gnu_regexp_RETokenPOSIX$sub_refs	gnu_regexp_RETokenPOSIX;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenPOSIX$sub_nonrefs {
	jint	type;
	jboolean	insens;
	jboolean	negated;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenPOSIX$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenPOSIX$sub_nonrefs	gnu_regexp_RETokenPOSIX;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenPOSIX$object {
	_jc_gnu_regexp_RETokenPOSIX$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenPOSIX$vtype	*vtype;
	_jc_gnu_regexp_RETokenPOSIX$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenPOSIX$vtype _jc_gnu_regexp_RETokenPOSIX$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenPOSIX, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenPOSIX$class_object;

#endif	/* _JC_gnu_regexp_RETokenPOSIX_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RETokenPOSIX.h <==
// final class gnu.regexp.RETokenPOSIX

// class file dependencies
// @dep_class 3c97b6b42ac22db4 gnu_regexp_REToken
// @dep_class 92fd4d13ee48f3ea gnu_regexp_RETokenPOSIX
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_regexp_REToken

#include "gnu/regexp/REToken.h"

#ifndef _JC_gnu_regexp_RETokenPOSIX_H_
#define _JC_gnu_regexp_RETokenPOSIX_H_

// Forward structure declarations
struct _jc_gnu_regexp_CharIndexed$object;
struct _jc_gnu_regexp_REMatch$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_StringBuffer$object;

// Typedefs
typedef struct _jc_gnu_regexp_RETokenPOSIX$sub_refs	_jc_gnu_regexp_RETokenPOSIX$sub_refs;
typedef struct _jc_gnu_regexp_RETokenPOSIX$sub_nonrefs	_jc_gnu_regexp_RETokenPOSIX$sub_nonrefs;
typedef struct _jc_gnu_regexp_RETokenPOSIX$refs	_jc_gnu_regexp_RETokenPOSIX$refs;
typedef struct _jc_gnu_regexp_RETokenPOSIX$nonrefs	_jc_gnu_regexp_RETokenPOSIX$nonrefs;
typedef struct _jc_gnu_regexp_RETokenPOSIX$object	_jc_gnu_regexp_RETokenPOSIX$object;

typedef struct _jc_gnu_regexp_RETokenPOSIX$fields_struct	_jc_gnu_regexp_RETokenPOSIX$fields_struct;
typedef const struct _jc_gnu_regexp_RETokenPOSIX$vmethods	_jc_gnu_regexp_RETokenPOSIX$vmethods;
typedef const struct _jc_gnu_regexp_RETokenPOSIX$vtable	_jc_gnu_regexp_RETokenPOSIX$vtable;
typedef const struct _jc_gnu_regexp_RETokenPOSIX$vtype	_jc_gnu_regexp_RETokenPOSIX$vtype;

// Class fields structure
struct _jc_gnu_regexp_RETokenPOSIX$fields_struct {
	_jc_object_array	*s__5fnameTable;
	jint	ALNUM;
	jint	ALPHA;
	jint	BLANK;
	jint	CNTRL;
	jint	DIGIT;
	jint	GRAPH;
	jint	LOWER;
	jint	PRINT;
	jint	PUNCT;
	jint	SPACE;
	jint	UPPER;
	jint	XDIGIT;
};
extern _jc_gnu_regexp_RETokenPOSIX$fields_struct _jc_gnu_regexp_RETokenPOSIX$class_fields;

// Constructors
extern void _jc_gnu_regexp_RETokenPOSIX$method$_init$bfa5e4ad51d4d34a(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_regexp_RETokenPOSIX$method$dump$9e5199210196a89c(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_RETokenPOSIX$method$getMinimumLength$13aeed906e65d975(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_RETokenPOSIX$method$match$d139de67a06a4f32(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_RETokenPOSIX$method_info$dump$9e5199210196a89c;
extern _jc_method _jc_gnu_regexp_RETokenPOSIX$method_info$getMinimumLength$13aeed906e65d975;
extern _jc_method _jc_gnu_regexp_RETokenPOSIX$method_info$match$d139de67a06a4f32;

// Static methods
extern void _jc_gnu_regexp_RETokenPOSIX$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jint _jc_gnu_regexp_RETokenPOSIX$method$intValue$f40b63b3de105c92(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_regexp_RETokenPOSIX$vmethods {
	void	(*dump$9e5199210196a89c)(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *, struct _jc_java_lang_StringBuffer$object *) _JC_JCNI_ATTR;
	jint	(*getMinimumLength$13aeed906e65d975)(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *) _JC_JCNI_ATTR;
	jboolean	(*match$d139de67a06a4f32)(_jc_env *, struct _jc_gnu_regexp_RETokenPOSIX$object *, struct _jc_object *, struct _jc_gnu_regexp_REMatch$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_RETokenPOSIX$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_REToken$vmethods	gnu_regexp_REToken;
	_jc_gnu_regexp_RETokenPOSIX$vmethods	gnu_regexp_RETokenPOSIX;
};

// Vtype
struct _jc_gnu_regexp_RETokenPOSIX$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RETokenPOSIX$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenPOSIX$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RETokenPOSIX$refs {
    _jc_gnu_regexp_RETokenPOSIX$sub_refs	gnu_regexp_RETokenPOSIX;
    _jc_gnu_regexp_REToken$sub_refs	gnu_regexp_REToken;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RETokenPOSIX$sub_nonrefs {
	jint	type;
	jboolean	insens;
	jboolean	negated;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RETokenPOSIX$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_REToken$sub_nonrefs	gnu_regexp_REToken;
    _jc_gnu_regexp_RETokenPOSIX$sub_nonrefs	gnu_regexp_RETokenPOSIX;
};

// Object instance structure
struct _jc_gnu_regexp_RETokenPOSIX$object {
	_jc_gnu_regexp_RETokenPOSIX$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RETokenPOSIX$vtype	*vtype;
	_jc_gnu_regexp_RETokenPOSIX$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RETokenPOSIX$vtype _jc_gnu_regexp_RETokenPOSIX$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RETokenPOSIX, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RETokenPOSIX$class_object;

#endif	/* _JC_gnu_regexp_RETokenPOSIX_H_ */
